==> haskell-witherable-0.4.2-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-I7jlVDVv3v0GYEqfwRMMS4
key:                  witherable-0.4.2-I7jlVDVv3v0GYEqfwRMMS4
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  47d3571a3c0f0c6895ba319b5898a661
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-I7jlVDVv3v0GYEqfwRMMS4
depends:
    base-4.17.2.1 base-orphans-0.9.1-2hOCfn2j6E6Chy4Kfvc1ON
    containers-0.6.7 hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    indexed-traversable-0.1.4-5gZqzfgqet6AnaoNtnMQi2
    indexed-traversable-instances-0.1.2-JJ8TzXleegR2jnUlLSqWc6
    transformers-0.5.6.2
    unordered-containers-0.2.20-7moq3V15ycBgVs1tpEAw
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-witherable-0.4.2-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witherable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.4.2
visibility:           public
id:                   witherable-0.4.2-Q7MwT5HsRv4pOEqebdg8
key:                  witherable-0.4.2-Q7MwT5HsRv4pOEqebdg8
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  7d2fb8e4c4da070eb80ba8a463cc3e5c
exposed:              True
exposed-modules:      Data.Witherable Witherable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/witherable-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.4.2-Q7MwT5HsRv4pOEqebdg8
depends:
    base-4.17.2.1 base-orphans-0.9.1-2hOCfn2j6E6Chy4Kfvc1ON
    containers-0.6.7 hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    indexed-traversable-0.1.4-DwddqQnU1k3Br4911kJWlg
    indexed-traversable-instances-0.1.2-EAhT9Qn8ZG53qaSd5Kf4Xl
    transformers-0.5.6.2
    unordered-containers-0.2.20-3jxCiK1Dn5HHqgJhQ3B9SH
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
